# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/fitness_service/constructs.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%qwak/fitness_service/constructs.proto\x12\x14qwak.fitness.service\"\xa2\x01\n\x0f\x42uildProperties\x12\x10\n\x08\x62uild_id\x18\x01 \x01(\t\x12\x0e\n\x06\x62ranch\x18\x02 \x01(\t\x12\x10\n\x08model_id\x18\x03 \x01(\t\x12\x0c\n\x04tags\x18\x04 \x03(\t\x12\x35\n\tmodel_uri\x18\x05 \x01(\x0b\x32\".qwak.fitness.service.ModelUriSpec\x12\x16\n\x0egpu_compatible\x18\x06 \x01(\x08\"\x8d\x01\n\x0cModelUriSpec\x12\x0b\n\x03uri\x18\x01 \x01(\t\x12\x12\n\ngit_branch\x18\x02 \x01(\t\x12\x17\n\x0fgit_credentials\x18\x03 \x01(\t\x12\x1e\n\x16git_credentials_secret\x18\x04 \x01(\t\x12\x11\n\tcommit_id\x18\x05 \x01(\t\x12\x10\n\x08main_dir\x18\x06 \x01(\t\"t\n\x08\x42uildEnv\x12\x33\n\ndocker_env\x18\x01 \x01(\x0b\x32\x1f.qwak.fitness.service.DockerEnv\x12\x33\n\npython_env\x18\x02 \x01(\x0b\x32\x1f.qwak.fitness.service.PythonEnv\"\x8a\x01\n\tDockerEnv\x12\x12\n\nbase_image\x18\x01 \x01(\t\x12\x10\n\x08\x65nv_vars\x18\x02 \x03(\t\x12\x10\n\x08no_cache\x18\x03 \x01(\x08\x12\x1c\n\x14\x61ssumed_iam_role_arn\x18\x04 \x01(\t\x12\'\n\x1fservice_account_key_secret_name\x18\x05 \x01(\t\"|\n\tPythonEnv\x12\x17\n\x0fgit_credentials\x18\x01 \x01(\t\x12\x1e\n\x16git_credentials_secret\x18\x02 \x01(\t\x12\x18\n\x10qwak_sdk_version\x18\x03 \x01(\t\x12\x1c\n\x14qwak_sdk_extra_index\x18\x04 \x01(\t\"j\n\x0c\x43puResources\x12\x0b\n\x03\x63pu\x18\x01 \x01(\x02\x12\x15\n\rmemory_amount\x18\x02 \x01(\x05\x12\x36\n\x0cmemory_units\x18\x03 \x01(\x0e\x32 .qwak.fitness.service.MemoryUnit\"\xaf\x01\n\x0cGpuResources\x12/\n\x08gpu_type\x18\x01 \x01(\x0e\x32\x1d.qwak.fitness.service.GpuType\x12\x12\n\ngpu_amount\x18\x02 \x01(\x05\x12\x0b\n\x03\x63pu\x18\x03 \x01(\x02\x12\x15\n\rmemory_amount\x18\x04 \x01(\x05\x12\x36\n\x0cmemory_units\x18\x05 \x01(\x0e\x32 .qwak.fitness.service.MemoryUnit*7\n\nMemoryUnit\x12\x17\n\x13UNKNOWN_MEMORY_UNIT\x10\x00\x12\x07\n\x03MIB\x10\x01\x12\x07\n\x03GIB\x10\x02*\x8c\x02\n\x07GpuType\x12\x0b\n\x07INVALID\x10\x00\x12\x0e\n\nNVIDIA_K80\x10\x01\x12\x0f\n\x0bNVIDIA_V100\x10\x02\x12\x0f\n\x0bNVIDIA_A100\x10\x03\x12\r\n\tNVIDIA_T4\x10\x04\x12\x0f\n\x0bNVIDIA_A10G\x10\x05\x12\r\n\tNVIDIA_L4\x10\x06\x12\x14\n\x10NVIDIA_T4_1_4_15\x10\x07\x12\x14\n\x10NVIDIA_T4_1_8_30\x10\x08\x12\x15\n\x11NVIDIA_T4_1_16_60\x10\t\x12\x1e\n\x1aNVIDIA_A100_80GB_8_96_1360\x10\n\x12\x16\n\x12NVIDIA_V100_1_8_52\x10\x0b\x12\x18\n\x14NVIDIA_V100_4_32_208\x10\x0c\x42#\n\x1f\x63om.qwak.ai.fitness.service.apiP\x01\x62\x06proto3')

_MEMORYUNIT = DESCRIPTOR.enum_types_by_name['MemoryUnit']
MemoryUnit = enum_type_wrapper.EnumTypeWrapper(_MEMORYUNIT)
_GPUTYPE = DESCRIPTOR.enum_types_by_name['GpuType']
GpuType = enum_type_wrapper.EnumTypeWrapper(_GPUTYPE)
UNKNOWN_MEMORY_UNIT = 0
MIB = 1
GIB = 2
INVALID = 0
NVIDIA_K80 = 1
NVIDIA_V100 = 2
NVIDIA_A100 = 3
NVIDIA_T4 = 4
NVIDIA_A10G = 5
NVIDIA_L4 = 6
NVIDIA_T4_1_4_15 = 7
NVIDIA_T4_1_8_30 = 8
NVIDIA_T4_1_16_60 = 9
NVIDIA_A100_80GB_8_96_1360 = 10
NVIDIA_V100_1_8_52 = 11
NVIDIA_V100_4_32_208 = 12


_BUILDPROPERTIES = DESCRIPTOR.message_types_by_name['BuildProperties']
_MODELURISPEC = DESCRIPTOR.message_types_by_name['ModelUriSpec']
_BUILDENV = DESCRIPTOR.message_types_by_name['BuildEnv']
_DOCKERENV = DESCRIPTOR.message_types_by_name['DockerEnv']
_PYTHONENV = DESCRIPTOR.message_types_by_name['PythonEnv']
_CPURESOURCES = DESCRIPTOR.message_types_by_name['CpuResources']
_GPURESOURCES = DESCRIPTOR.message_types_by_name['GpuResources']
BuildProperties = _reflection.GeneratedProtocolMessageType('BuildProperties', (_message.Message,), {
  'DESCRIPTOR' : _BUILDPROPERTIES,
  '__module__' : 'qwak.fitness_service.constructs_pb2'
  # @@protoc_insertion_point(class_scope:qwak.fitness.service.BuildProperties)
  })
_sym_db.RegisterMessage(BuildProperties)

ModelUriSpec = _reflection.GeneratedProtocolMessageType('ModelUriSpec', (_message.Message,), {
  'DESCRIPTOR' : _MODELURISPEC,
  '__module__' : 'qwak.fitness_service.constructs_pb2'
  # @@protoc_insertion_point(class_scope:qwak.fitness.service.ModelUriSpec)
  })
_sym_db.RegisterMessage(ModelUriSpec)

BuildEnv = _reflection.GeneratedProtocolMessageType('BuildEnv', (_message.Message,), {
  'DESCRIPTOR' : _BUILDENV,
  '__module__' : 'qwak.fitness_service.constructs_pb2'
  # @@protoc_insertion_point(class_scope:qwak.fitness.service.BuildEnv)
  })
_sym_db.RegisterMessage(BuildEnv)

DockerEnv = _reflection.GeneratedProtocolMessageType('DockerEnv', (_message.Message,), {
  'DESCRIPTOR' : _DOCKERENV,
  '__module__' : 'qwak.fitness_service.constructs_pb2'
  # @@protoc_insertion_point(class_scope:qwak.fitness.service.DockerEnv)
  })
_sym_db.RegisterMessage(DockerEnv)

PythonEnv = _reflection.GeneratedProtocolMessageType('PythonEnv', (_message.Message,), {
  'DESCRIPTOR' : _PYTHONENV,
  '__module__' : 'qwak.fitness_service.constructs_pb2'
  # @@protoc_insertion_point(class_scope:qwak.fitness.service.PythonEnv)
  })
_sym_db.RegisterMessage(PythonEnv)

CpuResources = _reflection.GeneratedProtocolMessageType('CpuResources', (_message.Message,), {
  'DESCRIPTOR' : _CPURESOURCES,
  '__module__' : 'qwak.fitness_service.constructs_pb2'
  # @@protoc_insertion_point(class_scope:qwak.fitness.service.CpuResources)
  })
_sym_db.RegisterMessage(CpuResources)

GpuResources = _reflection.GeneratedProtocolMessageType('GpuResources', (_message.Message,), {
  'DESCRIPTOR' : _GPURESOURCES,
  '__module__' : 'qwak.fitness_service.constructs_pb2'
  # @@protoc_insertion_point(class_scope:qwak.fitness.service.GpuResources)
  })
_sym_db.RegisterMessage(GpuResources)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\037com.qwak.ai.fitness.service.apiP\001'
  _MEMORYUNIT._serialized_start=1043
  _MEMORYUNIT._serialized_end=1098
  _GPUTYPE._serialized_start=1101
  _GPUTYPE._serialized_end=1369
  _BUILDPROPERTIES._serialized_start=64
  _BUILDPROPERTIES._serialized_end=226
  _MODELURISPEC._serialized_start=229
  _MODELURISPEC._serialized_end=370
  _BUILDENV._serialized_start=372
  _BUILDENV._serialized_end=488
  _DOCKERENV._serialized_start=491
  _DOCKERENV._serialized_end=629
  _PYTHONENV._serialized_start=631
  _PYTHONENV._serialized_end=755
  _CPURESOURCES._serialized_start=757
  _CPURESOURCES._serialized_end=863
  _GPURESOURCES._serialized_start=866
  _GPURESOURCES._serialized_end=1041
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/monitoring/v0/alerting_channel.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)qwak/monitoring/v0/alerting_channel.proto\x12\x12qwak.monitoring.v0\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\"c\n\x1c\x41lertingChannelCreateOptions\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x35\n\x04spec\x18\x02 \x01(\x0b\x32\'.qwak.monitoring.v0.AlertingChannelSpec\"\x8d\x01\n\x1c\x41lertingChannelUpdateOptions\x12\n\n\x02id\x18\x01 \x01(\t\x12*\n\x04name\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x35\n\x04spec\x18\x03 \x01(\x0b\x32\'.qwak.monitoring.v0.AlertingChannelSpec\"\x92\x01\n\x1a\x41lertingChannelDescription\x12=\n\x08metadata\x18\x01 \x01(\x0b\x32+.qwak.monitoring.v0.AlertingChannelMetadata\x12\x35\n\x04spec\x18\x02 \x01(\x0b\x32\'.qwak.monitoring.v0.AlertingChannelSpec\"\xdd\x01\n\x17\x41lertingChannelMetadata\x12\x12\n\naccount_id\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12.\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x34\n\x10last_modified_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\ndeleted_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"V\n\x13\x41lertingChannelSpec\x12?\n\rconfiguration\x18\x01 \x01(\x0b\x32(.qwak.monitoring.v0.ChannelConfiguration\"\xc4\x01\n\x14\x43hannelConfiguration\x12.\n\x05slack\x18\x01 \x01(\x0b\x32\x1d.qwak.monitoring.v0.SlackTypeH\x00\x12\x36\n\tpagerduty\x18\x02 \x01(\x0b\x32!.qwak.monitoring.v0.PagerDutyTypeH\x00\x12\x34\n\x08opsgenie\x18\x03 \x01(\x0b\x32 .qwak.monitoring.v0.OpsgenieTypeH\x00\x42\x0e\n\x0c\x63hannel_type\"\xb1\x01\n\x0cSyncResponse\x12\x45\n\x10\x63hannels_to_sync\x18\x01 \x01(\x0b\x32).qwak.monitoring.v0.AlertingChannelToSyncH\x00\x12Q\n\x12\x61lready_up_to_date\x18\x02 \x01(\x0b\x32\x33.qwak.monitoring.v0.AlertingChannelsAlreadyUpToDateH\x00\x42\x07\n\x05types\"\xa8\x01\n\x15\x41lertingChannelToSync\x12\x43\n\x0b\x64\x65scription\x18\x01 \x03(\x0b\x32..qwak.monitoring.v0.AlertingChannelDescription\x12J\n\x12\x63hannels_to_delete\x18\x03 \x03(\x0b\x32..qwak.monitoring.v0.AlertingChannelDescription\"^\n\x17\x41lertingChannelToDelete\x12\x43\n\x0b\x64\x65scription\x18\x01 \x03(\x0b\x32..qwak.monitoring.v0.AlertingChannelDescription\"!\n\x1f\x41lertingChannelsAlreadyUpToDate\"C\n\tSlackType\x12\x36\n\x07\x61pi_url\x18\x01 \x01(\x0b\x32%.qwak.monitoring.v0.SecretStringValue\"\x94\x01\n\rPagerDutyType\x12:\n\x0brouting_key\x18\x01 \x01(\x0b\x32%.qwak.monitoring.v0.SecretStringValue\x12:\n\x0bservice_key\x18\x02 \x01(\x0b\x32%.qwak.monitoring.v0.SecretStringValue\x12\x0b\n\x03url\x18\x03 \x01(\t\"F\n\x0cOpsgenieType\x12\x36\n\x07\x61pi_key\x18\x01 \x01(\x0b\x32%.qwak.monitoring.v0.SecretStringValue\"\"\n\x11SecretStringValue\x12\r\n\x05value\x18\x01 \x01(\t*k\n\x15MonitorActivityStatus\x12\x1a\n\x16MONITOR_STATUS_INVALID\x10\x00\x12\x19\n\x15MONITOR_STATUS_ACTIVE\x10\x01\x12\x1b\n\x17MONITOR_STATUS_DISABLED\x10\x02\x42\x32\n\x1d\x63om.qwak.ai.monitoring.api.v0P\x01Z\x0f.;monitoring_v0b\x06proto3')

_MONITORACTIVITYSTATUS = DESCRIPTOR.enum_types_by_name['MonitorActivityStatus']
MonitorActivityStatus = enum_type_wrapper.EnumTypeWrapper(_MONITORACTIVITYSTATUS)
MONITOR_STATUS_INVALID = 0
MONITOR_STATUS_ACTIVE = 1
MONITOR_STATUS_DISABLED = 2


_ALERTINGCHANNELCREATEOPTIONS = DESCRIPTOR.message_types_by_name['AlertingChannelCreateOptions']
_ALERTINGCHANNELUPDATEOPTIONS = DESCRIPTOR.message_types_by_name['AlertingChannelUpdateOptions']
_ALERTINGCHANNELDESCRIPTION = DESCRIPTOR.message_types_by_name['AlertingChannelDescription']
_ALERTINGCHANNELMETADATA = DESCRIPTOR.message_types_by_name['AlertingChannelMetadata']
_ALERTINGCHANNELSPEC = DESCRIPTOR.message_types_by_name['AlertingChannelSpec']
_CHANNELCONFIGURATION = DESCRIPTOR.message_types_by_name['ChannelConfiguration']
_SYNCRESPONSE = DESCRIPTOR.message_types_by_name['SyncResponse']
_ALERTINGCHANNELTOSYNC = DESCRIPTOR.message_types_by_name['AlertingChannelToSync']
_ALERTINGCHANNELTODELETE = DESCRIPTOR.message_types_by_name['AlertingChannelToDelete']
_ALERTINGCHANNELSALREADYUPTODATE = DESCRIPTOR.message_types_by_name['AlertingChannelsAlreadyUpToDate']
_SLACKTYPE = DESCRIPTOR.message_types_by_name['SlackType']
_PAGERDUTYTYPE = DESCRIPTOR.message_types_by_name['PagerDutyType']
_OPSGENIETYPE = DESCRIPTOR.message_types_by_name['OpsgenieType']
_SECRETSTRINGVALUE = DESCRIPTOR.message_types_by_name['SecretStringValue']
AlertingChannelCreateOptions = _reflection.GeneratedProtocolMessageType('AlertingChannelCreateOptions', (_message.Message,), {
  'DESCRIPTOR' : _ALERTINGCHANNELCREATEOPTIONS,
  '__module__' : 'qwak.monitoring.v0.alerting_channel_pb2'
  # @@protoc_insertion_point(class_scope:qwak.monitoring.v0.AlertingChannelCreateOptions)
  })
_sym_db.RegisterMessage(AlertingChannelCreateOptions)

AlertingChannelUpdateOptions = _reflection.GeneratedProtocolMessageType('AlertingChannelUpdateOptions', (_message.Message,), {
  'DESCRIPTOR' : _ALERTINGCHANNELUPDATEOPTIONS,
  '__module__' : 'qwak.monitoring.v0.alerting_channel_pb2'
  # @@protoc_insertion_point(class_scope:qwak.monitoring.v0.AlertingChannelUpdateOptions)
  })
_sym_db.RegisterMessage(AlertingChannelUpdateOptions)

AlertingChannelDescription = _reflection.GeneratedProtocolMessageType('AlertingChannelDescription', (_message.Message,), {
  'DESCRIPTOR' : _ALERTINGCHANNELDESCRIPTION,
  '__module__' : 'qwak.monitoring.v0.alerting_channel_pb2'
  # @@protoc_insertion_point(class_scope:qwak.monitoring.v0.AlertingChannelDescription)
  })
_sym_db.RegisterMessage(AlertingChannelDescription)

AlertingChannelMetadata = _reflection.GeneratedProtocolMessageType('AlertingChannelMetadata', (_message.Message,), {
  'DESCRIPTOR' : _ALERTINGCHANNELMETADATA,
  '__module__' : 'qwak.monitoring.v0.alerting_channel_pb2'
  # @@protoc_insertion_point(class_scope:qwak.monitoring.v0.AlertingChannelMetadata)
  })
_sym_db.RegisterMessage(AlertingChannelMetadata)

AlertingChannelSpec = _reflection.GeneratedProtocolMessageType('AlertingChannelSpec', (_message.Message,), {
  'DESCRIPTOR' : _ALERTINGCHANNELSPEC,
  '__module__' : 'qwak.monitoring.v0.alerting_channel_pb2'
  # @@protoc_insertion_point(class_scope:qwak.monitoring.v0.AlertingChannelSpec)
  })
_sym_db.RegisterMessage(AlertingChannelSpec)

ChannelConfiguration = _reflection.GeneratedProtocolMessageType('ChannelConfiguration', (_message.Message,), {
  'DESCRIPTOR' : _CHANNELCONFIGURATION,
  '__module__' : 'qwak.monitoring.v0.alerting_channel_pb2'
  # @@protoc_insertion_point(class_scope:qwak.monitoring.v0.ChannelConfiguration)
  })
_sym_db.RegisterMessage(ChannelConfiguration)

SyncResponse = _reflection.GeneratedProtocolMessageType('SyncResponse', (_message.Message,), {
  'DESCRIPTOR' : _SYNCRESPONSE,
  '__module__' : 'qwak.monitoring.v0.alerting_channel_pb2'
  # @@protoc_insertion_point(class_scope:qwak.monitoring.v0.SyncResponse)
  })
_sym_db.RegisterMessage(SyncResponse)

AlertingChannelToSync = _reflection.GeneratedProtocolMessageType('AlertingChannelToSync', (_message.Message,), {
  'DESCRIPTOR' : _ALERTINGCHANNELTOSYNC,
  '__module__' : 'qwak.monitoring.v0.alerting_channel_pb2'
  # @@protoc_insertion_point(class_scope:qwak.monitoring.v0.AlertingChannelToSync)
  })
_sym_db.RegisterMessage(AlertingChannelToSync)

AlertingChannelToDelete = _reflection.GeneratedProtocolMessageType('AlertingChannelToDelete', (_message.Message,), {
  'DESCRIPTOR' : _ALERTINGCHANNELTODELETE,
  '__module__' : 'qwak.monitoring.v0.alerting_channel_pb2'
  # @@protoc_insertion_point(class_scope:qwak.monitoring.v0.AlertingChannelToDelete)
  })
_sym_db.RegisterMessage(AlertingChannelToDelete)

AlertingChannelsAlreadyUpToDate = _reflection.GeneratedProtocolMessageType('AlertingChannelsAlreadyUpToDate', (_message.Message,), {
  'DESCRIPTOR' : _ALERTINGCHANNELSALREADYUPTODATE,
  '__module__' : 'qwak.monitoring.v0.alerting_channel_pb2'
  # @@protoc_insertion_point(class_scope:qwak.monitoring.v0.AlertingChannelsAlreadyUpToDate)
  })
_sym_db.RegisterMessage(AlertingChannelsAlreadyUpToDate)

SlackType = _reflection.GeneratedProtocolMessageType('SlackType', (_message.Message,), {
  'DESCRIPTOR' : _SLACKTYPE,
  '__module__' : 'qwak.monitoring.v0.alerting_channel_pb2'
  # @@protoc_insertion_point(class_scope:qwak.monitoring.v0.SlackType)
  })
_sym_db.RegisterMessage(SlackType)

PagerDutyType = _reflection.GeneratedProtocolMessageType('PagerDutyType', (_message.Message,), {
  'DESCRIPTOR' : _PAGERDUTYTYPE,
  '__module__' : 'qwak.monitoring.v0.alerting_channel_pb2'
  # @@protoc_insertion_point(class_scope:qwak.monitoring.v0.PagerDutyType)
  })
_sym_db.RegisterMessage(PagerDutyType)

OpsgenieType = _reflection.GeneratedProtocolMessageType('OpsgenieType', (_message.Message,), {
  'DESCRIPTOR' : _OPSGENIETYPE,
  '__module__' : 'qwak.monitoring.v0.alerting_channel_pb2'
  # @@protoc_insertion_point(class_scope:qwak.monitoring.v0.OpsgenieType)
  })
_sym_db.RegisterMessage(OpsgenieType)

SecretStringValue = _reflection.GeneratedProtocolMessageType('SecretStringValue', (_message.Message,), {
  'DESCRIPTOR' : _SECRETSTRINGVALUE,
  '__module__' : 'qwak.monitoring.v0.alerting_channel_pb2'
  # @@protoc_insertion_point(class_scope:qwak.monitoring.v0.SecretStringValue)
  })
_sym_db.RegisterMessage(SecretStringValue)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035com.qwak.ai.monitoring.api.v0P\001Z\017.;monitoring_v0'
  _MONITORACTIVITYSTATUS._serialized_start=1845
  _MONITORACTIVITYSTATUS._serialized_end=1952
  _ALERTINGCHANNELCREATEOPTIONS._serialized_start=130
  _ALERTINGCHANNELCREATEOPTIONS._serialized_end=229
  _ALERTINGCHANNELUPDATEOPTIONS._serialized_start=232
  _ALERTINGCHANNELUPDATEOPTIONS._serialized_end=373
  _ALERTINGCHANNELDESCRIPTION._serialized_start=376
  _ALERTINGCHANNELDESCRIPTION._serialized_end=522
  _ALERTINGCHANNELMETADATA._serialized_start=525
  _ALERTINGCHANNELMETADATA._serialized_end=746
  _ALERTINGCHANNELSPEC._serialized_start=748
  _ALERTINGCHANNELSPEC._serialized_end=834
  _CHANNELCONFIGURATION._serialized_start=837
  _CHANNELCONFIGURATION._serialized_end=1033
  _SYNCRESPONSE._serialized_start=1036
  _SYNCRESPONSE._serialized_end=1213
  _ALERTINGCHANNELTOSYNC._serialized_start=1216
  _ALERTINGCHANNELTOSYNC._serialized_end=1384
  _ALERTINGCHANNELTODELETE._serialized_start=1386
  _ALERTINGCHANNELTODELETE._serialized_end=1480
  _ALERTINGCHANNELSALREADYUPTODATE._serialized_start=1482
  _ALERTINGCHANNELSALREADYUPTODATE._serialized_end=1515
  _SLACKTYPE._serialized_start=1517
  _SLACKTYPE._serialized_end=1584
  _PAGERDUTYTYPE._serialized_start=1587
  _PAGERDUTYTYPE._serialized_end=1735
  _OPSGENIETYPE._serialized_start=1737
  _OPSGENIETYPE._serialized_end=1807
  _SECRETSTRINGVALUE._serialized_start=1809
  _SECRETSTRINGVALUE._serialized_end=1843
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/admiral/secret/v0/secret.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#qwak/admiral/secret/v0/secret.proto\x12\x16qwak.admiral.secret.v0\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x1f\n\x0eUserSecretSpec\x12\r\n\x05value\x18\x02 \x01(\t\"L\n\x10SystemSecretSpec\x12\x38\n\x05value\x18\x02 \x01(\x0b\x32).qwak.admiral.secret.v0.SystemSecretValue\"\x99\x01\n\x16SystemSecretDefinition\x12G\n\nidentifier\x18\x01 \x01(\x0b\x32\x33.qwak.admiral.secret.v0.EnvironmentSecretIdentifier\x12\x36\n\x04spec\x18\x02 \x01(\x0b\x32(.qwak.admiral.secret.v0.SystemSecretSpec\"C\n\x1b\x45nvironmentSecretIdentifier\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x16\n\x0e\x65nvironment_id\x18\x02 \x01(\t\"\xa0\x01\n\x1fSetUserEnvironmentSecretOptions\x12G\n\nidentifier\x18\x01 \x01(\x0b\x32\x33.qwak.admiral.secret.v0.EnvironmentSecretIdentifier\x12\x34\n\x04spec\x18\x02 \x01(\x0b\x32&.qwak.admiral.secret.v0.UserSecretSpec\"\xa4\x01\n!SetSystemEnvironmentSecretOptions\x12G\n\nidentifier\x18\x01 \x01(\x0b\x32\x33.qwak.admiral.secret.v0.EnvironmentSecretIdentifier\x12\x36\n\x04spec\x18\x02 \x01(\x0b\x32(.qwak.admiral.secret.v0.SystemSecretSpec\"\xa5\x01\n\x11SystemSecretValue\x12\x10\n\x06opaque\x18\x02 \x01(\tH\x00\x12\x35\n\x12\x64ocker_config_json\x18\x03 \x01(\x0b\x32\x17.google.protobuf.StructH\x00\x12>\n\x0bopaque_pair\x18\x04 \x01(\x0b\x32\'.qwak.admiral.secret.v0.OpaquePairValueH\x00\x42\x07\n\x05value\"\x82\x01\n\x0fOpaquePairValue\x12\x41\n\x05pairs\x18\x04 \x03(\x0b\x32\x32.qwak.admiral.secret.v0.OpaquePairValue.PairsEntry\x1a,\n\nPairsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"T\n\x0e\x41\x63\x63ountSecrets\x12\x42\n\x07secrets\x18\x01 \x03(\x0b\x32\x31.qwak.admiral.secret.v0.EnvironmentSecretMetadata\"\xc9\x01\n\x19\x45nvironmentSecretMetadata\x12G\n\nidentifier\x18\x01 \x01(\x0b\x32\x33.qwak.admiral.secret.v0.EnvironmentSecretIdentifier\x12.\n\ncreated_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x33\n\x0flast_updated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x8c\x01\n\x1d\x63om.qwak.ai.admiral.secret.v0P\x01Zigithub.com/qwak-ai/qwak-platform/services/core/go/admiral/admiral-api/pb/qwak/admiral/secret/v0;secret_v0b\x06proto3')



_USERSECRETSPEC = DESCRIPTOR.message_types_by_name['UserSecretSpec']
_SYSTEMSECRETSPEC = DESCRIPTOR.message_types_by_name['SystemSecretSpec']
_SYSTEMSECRETDEFINITION = DESCRIPTOR.message_types_by_name['SystemSecretDefinition']
_ENVIRONMENTSECRETIDENTIFIER = DESCRIPTOR.message_types_by_name['EnvironmentSecretIdentifier']
_SETUSERENVIRONMENTSECRETOPTIONS = DESCRIPTOR.message_types_by_name['SetUserEnvironmentSecretOptions']
_SETSYSTEMENVIRONMENTSECRETOPTIONS = DESCRIPTOR.message_types_by_name['SetSystemEnvironmentSecretOptions']
_SYSTEMSECRETVALUE = DESCRIPTOR.message_types_by_name['SystemSecretValue']
_OPAQUEPAIRVALUE = DESCRIPTOR.message_types_by_name['OpaquePairValue']
_OPAQUEPAIRVALUE_PAIRSENTRY = _OPAQUEPAIRVALUE.nested_types_by_name['PairsEntry']
_ACCOUNTSECRETS = DESCRIPTOR.message_types_by_name['AccountSecrets']
_ENVIRONMENTSECRETMETADATA = DESCRIPTOR.message_types_by_name['EnvironmentSecretMetadata']
UserSecretSpec = _reflection.GeneratedProtocolMessageType('UserSecretSpec', (_message.Message,), {
  'DESCRIPTOR' : _USERSECRETSPEC,
  '__module__' : 'qwak.admiral.secret.v0.secret_pb2'
  # @@protoc_insertion_point(class_scope:qwak.admiral.secret.v0.UserSecretSpec)
  })
_sym_db.RegisterMessage(UserSecretSpec)

SystemSecretSpec = _reflection.GeneratedProtocolMessageType('SystemSecretSpec', (_message.Message,), {
  'DESCRIPTOR' : _SYSTEMSECRETSPEC,
  '__module__' : 'qwak.admiral.secret.v0.secret_pb2'
  # @@protoc_insertion_point(class_scope:qwak.admiral.secret.v0.SystemSecretSpec)
  })
_sym_db.RegisterMessage(SystemSecretSpec)

SystemSecretDefinition = _reflection.GeneratedProtocolMessageType('SystemSecretDefinition', (_message.Message,), {
  'DESCRIPTOR' : _SYSTEMSECRETDEFINITION,
  '__module__' : 'qwak.admiral.secret.v0.secret_pb2'
  # @@protoc_insertion_point(class_scope:qwak.admiral.secret.v0.SystemSecretDefinition)
  })
_sym_db.RegisterMessage(SystemSecretDefinition)

EnvironmentSecretIdentifier = _reflection.GeneratedProtocolMessageType('EnvironmentSecretIdentifier', (_message.Message,), {
  'DESCRIPTOR' : _ENVIRONMENTSECRETIDENTIFIER,
  '__module__' : 'qwak.admiral.secret.v0.secret_pb2'
  # @@protoc_insertion_point(class_scope:qwak.admiral.secret.v0.EnvironmentSecretIdentifier)
  })
_sym_db.RegisterMessage(EnvironmentSecretIdentifier)

SetUserEnvironmentSecretOptions = _reflection.GeneratedProtocolMessageType('SetUserEnvironmentSecretOptions', (_message.Message,), {
  'DESCRIPTOR' : _SETUSERENVIRONMENTSECRETOPTIONS,
  '__module__' : 'qwak.admiral.secret.v0.secret_pb2'
  # @@protoc_insertion_point(class_scope:qwak.admiral.secret.v0.SetUserEnvironmentSecretOptions)
  })
_sym_db.RegisterMessage(SetUserEnvironmentSecretOptions)

SetSystemEnvironmentSecretOptions = _reflection.GeneratedProtocolMessageType('SetSystemEnvironmentSecretOptions', (_message.Message,), {
  'DESCRIPTOR' : _SETSYSTEMENVIRONMENTSECRETOPTIONS,
  '__module__' : 'qwak.admiral.secret.v0.secret_pb2'
  # @@protoc_insertion_point(class_scope:qwak.admiral.secret.v0.SetSystemEnvironmentSecretOptions)
  })
_sym_db.RegisterMessage(SetSystemEnvironmentSecretOptions)

SystemSecretValue = _reflection.GeneratedProtocolMessageType('SystemSecretValue', (_message.Message,), {
  'DESCRIPTOR' : _SYSTEMSECRETVALUE,
  '__module__' : 'qwak.admiral.secret.v0.secret_pb2'
  # @@protoc_insertion_point(class_scope:qwak.admiral.secret.v0.SystemSecretValue)
  })
_sym_db.RegisterMessage(SystemSecretValue)

OpaquePairValue = _reflection.GeneratedProtocolMessageType('OpaquePairValue', (_message.Message,), {

  'PairsEntry' : _reflection.GeneratedProtocolMessageType('PairsEntry', (_message.Message,), {
    'DESCRIPTOR' : _OPAQUEPAIRVALUE_PAIRSENTRY,
    '__module__' : 'qwak.admiral.secret.v0.secret_pb2'
    # @@protoc_insertion_point(class_scope:qwak.admiral.secret.v0.OpaquePairValue.PairsEntry)
    })
  ,
  'DESCRIPTOR' : _OPAQUEPAIRVALUE,
  '__module__' : 'qwak.admiral.secret.v0.secret_pb2'
  # @@protoc_insertion_point(class_scope:qwak.admiral.secret.v0.OpaquePairValue)
  })
_sym_db.RegisterMessage(OpaquePairValue)
_sym_db.RegisterMessage(OpaquePairValue.PairsEntry)

AccountSecrets = _reflection.GeneratedProtocolMessageType('AccountSecrets', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTSECRETS,
  '__module__' : 'qwak.admiral.secret.v0.secret_pb2'
  # @@protoc_insertion_point(class_scope:qwak.admiral.secret.v0.AccountSecrets)
  })
_sym_db.RegisterMessage(AccountSecrets)

EnvironmentSecretMetadata = _reflection.GeneratedProtocolMessageType('EnvironmentSecretMetadata', (_message.Message,), {
  'DESCRIPTOR' : _ENVIRONMENTSECRETMETADATA,
  '__module__' : 'qwak.admiral.secret.v0.secret_pb2'
  # @@protoc_insertion_point(class_scope:qwak.admiral.secret.v0.EnvironmentSecretMetadata)
  })
_sym_db.RegisterMessage(EnvironmentSecretMetadata)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035com.qwak.ai.admiral.secret.v0P\001Zigithub.com/qwak-ai/qwak-platform/services/core/go/admiral/admiral-api/pb/qwak/admiral/secret/v0;secret_v0'
  _OPAQUEPAIRVALUE_PAIRSENTRY._options = None
  _OPAQUEPAIRVALUE_PAIRSENTRY._serialized_options = b'8\001'
  _USERSECRETSPEC._serialized_start=126
  _USERSECRETSPEC._serialized_end=157
  _SYSTEMSECRETSPEC._serialized_start=159
  _SYSTEMSECRETSPEC._serialized_end=235
  _SYSTEMSECRETDEFINITION._serialized_start=238
  _SYSTEMSECRETDEFINITION._serialized_end=391
  _ENVIRONMENTSECRETIDENTIFIER._serialized_start=393
  _ENVIRONMENTSECRETIDENTIFIER._serialized_end=460
  _SETUSERENVIRONMENTSECRETOPTIONS._serialized_start=463
  _SETUSERENVIRONMENTSECRETOPTIONS._serialized_end=623
  _SETSYSTEMENVIRONMENTSECRETOPTIONS._serialized_start=626
  _SETSYSTEMENVIRONMENTSECRETOPTIONS._serialized_end=790
  _SYSTEMSECRETVALUE._serialized_start=793
  _SYSTEMSECRETVALUE._serialized_end=958
  _OPAQUEPAIRVALUE._serialized_start=961
  _OPAQUEPAIRVALUE._serialized_end=1091
  _OPAQUEPAIRVALUE_PAIRSENTRY._serialized_start=1047
  _OPAQUEPAIRVALUE_PAIRSENTRY._serialized_end=1091
  _ACCOUNTSECRETS._serialized_start=1093
  _ACCOUNTSECRETS._serialized_end=1177
  _ENVIRONMENTSECRETMETADATA._serialized_start=1180
  _ENVIRONMENTSECRETMETADATA._serialized_end=1381
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/fitness_service/fitness.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.fitness_service import constructs_pb2 as qwak_dot_fitness__service_dot_constructs__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"qwak/fitness_service/fitness.proto\x12\x14qwak.fitness.service\x1a%qwak/fitness_service/constructs.proto\"\x8b\x04\n\tBuildSpec\x12?\n\x10\x62uild_properties\x18\x01 \x01(\x0b\x32%.qwak.fitness.service.BuildProperties\x12\x31\n\tbuild_env\x18\x02 \x01(\x0b\x32\x1e.qwak.fitness.service.BuildEnv\x12;\n\rcpu_resources\x18\x03 \x01(\x0b\x32\".qwak.fitness.service.CpuResourcesH\x00\x12;\n\rgpu_resources\x18\x07 \x01(\x0b\x32\".qwak.fitness.service.GpuResourcesH\x00\x12\x0f\n\x07verbose\x18\x04 \x01(\x05\x12\x14\n\x0c\x62uild_config\x18\x05 \x01(\t\x12\x15\n\rbuild_v1_flag\x18\x06 \x01(\x08\x12\x44\n\x13\x62uild_properties_v1\x18\x08 \x01(\x0b\x32\'.qwak.fitness.service.BuildPropertiesV1\x12=\n\x0fpurchase_option\x18\t \x01(\x0e\x32$.qwak.fitness.service.PurchaseOption\x12\x1c\n\x14\x62uild_destined_image\x18\n \x01(\t\x12\"\n\x1aprovision_instance_timeout\x18\x0b \x01(\x05\x42\x0b\n\tResources\"g\n\x11\x42uildPropertiesV1\x12\x18\n\x10\x62uild_config_url\x18\x01 \x01(\t\x12\x1a\n\x12qwak_sdk_wheel_url\x18\x02 \x01(\t\x12\x1c\n\x14qwak_sdk_version_url\x18\x03 \x01(\t*e\n\x0ePurchaseOption\x12\x1b\n\x17INVALID_PURCHASE_OPTION\x10\x00\x12\x18\n\x14SPOT_PURCHASE_OPTION\x10\x01\x12\x1c\n\x18ONDEMAND_PURCHASE_OPTION\x10\x02\x42#\n\x1f\x63om.qwak.ai.fitness.service.apiP\x01\x62\x06proto3')

_PURCHASEOPTION = DESCRIPTOR.enum_types_by_name['PurchaseOption']
PurchaseOption = enum_type_wrapper.EnumTypeWrapper(_PURCHASEOPTION)
INVALID_PURCHASE_OPTION = 0
SPOT_PURCHASE_OPTION = 1
ONDEMAND_PURCHASE_OPTION = 2


_BUILDSPEC = DESCRIPTOR.message_types_by_name['BuildSpec']
_BUILDPROPERTIESV1 = DESCRIPTOR.message_types_by_name['BuildPropertiesV1']
BuildSpec = _reflection.GeneratedProtocolMessageType('BuildSpec', (_message.Message,), {
  'DESCRIPTOR' : _BUILDSPEC,
  '__module__' : 'qwak.fitness_service.fitness_pb2'
  # @@protoc_insertion_point(class_scope:qwak.fitness.service.BuildSpec)
  })
_sym_db.RegisterMessage(BuildSpec)

BuildPropertiesV1 = _reflection.GeneratedProtocolMessageType('BuildPropertiesV1', (_message.Message,), {
  'DESCRIPTOR' : _BUILDPROPERTIESV1,
  '__module__' : 'qwak.fitness_service.fitness_pb2'
  # @@protoc_insertion_point(class_scope:qwak.fitness.service.BuildPropertiesV1)
  })
_sym_db.RegisterMessage(BuildPropertiesV1)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\037com.qwak.ai.fitness.service.apiP\001'
  _PURCHASEOPTION._serialized_start=730
  _PURCHASEOPTION._serialized_end=831
  _BUILDSPEC._serialized_start=100
  _BUILDSPEC._serialized_end=623
  _BUILDPROPERTIESV1._serialized_start=625
  _BUILDPROPERTIESV1._serialized_end=728
# @@protoc_insertion_point(module_scope)



from qwak.exceptions import QuietError


class QwakExternalException(QuietError):
    """
    An external system to Qwak, had an internal error
    """

    def __init__(self, message):
        super().__init__(message)
        self.message = message



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _MetricThresholdDirection:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _MetricThresholdDirectionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_MetricThresholdDirection.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    INVALID_METRIC_DIRECTION: _MetricThresholdDirection.ValueType  # 0
    BELOW: _MetricThresholdDirection.ValueType  # 1
    ABOVE: _MetricThresholdDirection.ValueType  # 2
    EQUALS: _MetricThresholdDirection.ValueType  # 3
    BELOW_OR_EQUALS: _MetricThresholdDirection.ValueType  # 4
    ABOVE_OR_EQUALS: _MetricThresholdDirection.ValueType  # 5

class MetricThresholdDirection(_MetricThresholdDirection, metaclass=_MetricThresholdDirectionEnumTypeWrapper): ...

INVALID_METRIC_DIRECTION: MetricThresholdDirection.ValueType  # 0
BELOW: MetricThresholdDirection.ValueType  # 1
ABOVE: MetricThresholdDirection.ValueType  # 2
EQUALS: MetricThresholdDirection.ValueType  # 3
BELOW_OR_EQUALS: MetricThresholdDirection.ValueType  # 4
ABOVE_OR_EQUALS: MetricThresholdDirection.ValueType  # 5
global___MetricThresholdDirection = MetricThresholdDirection

class Metric(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SQL_METRIC_FIELD_NUMBER: builtins.int
    @property
    def sql_metric(self) -> global___SqlMetric: ...
    def __init__(
        self,
        *,
        sql_metric: global___SqlMetric | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metric", b"metric", "sql_metric", b"sql_metric"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["metric", b"metric", "sql_metric", b"sql_metric"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["metric", b"metric"]) -> typing_extensions.Literal["sql_metric"] | None: ...

global___Metric = Metric

class SqlMetric(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SQL_QUERY_FIELD_NUMBER: builtins.int
    sql_query: builtins.str
    def __init__(
        self,
        *,
        sql_query: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["sql_query", b"sql_query"]) -> None: ...

global___SqlMetric = SqlMetric



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from _qwak_proto.qwak.prompt.v1.prompt import prompt_manager_service_pb2 as qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2


class PromptManagerServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreatePrompt = channel.unary_unary(
                '/qwak.prompt.v1.prompt.PromptManagerService/CreatePrompt',
                request_serializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.CreatePromptRequest.SerializeToString,
                response_deserializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.CreatePromptResponse.FromString,
                )
        self.CreatePromptVersion = channel.unary_unary(
                '/qwak.prompt.v1.prompt.PromptManagerService/CreatePromptVersion',
                request_serializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.CreatePromptVersionRequest.SerializeToString,
                response_deserializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.CreatePromptVersionResponse.FromString,
                )
        self.UpdatePrompt = channel.unary_unary(
                '/qwak.prompt.v1.prompt.PromptManagerService/UpdatePrompt',
                request_serializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.UpdatePromptRequest.SerializeToString,
                response_deserializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.UpdatePromptResponse.FromString,
                )
        self.GetPromptByName = channel.unary_unary(
                '/qwak.prompt.v1.prompt.PromptManagerService/GetPromptByName',
                request_serializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.GetPromptByNameRequest.SerializeToString,
                response_deserializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.GetPromptByNameResponse.FromString,
                )
        self.ListPrompts = channel.unary_unary(
                '/qwak.prompt.v1.prompt.PromptManagerService/ListPrompts',
                request_serializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.ListPromptsRequest.SerializeToString,
                response_deserializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.ListPromptsResponse.FromString,
                )
        self.GetPromptVersionByPromptName = channel.unary_unary(
                '/qwak.prompt.v1.prompt.PromptManagerService/GetPromptVersionByPromptName',
                request_serializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.GetPromptVersionByPromptNameRequest.SerializeToString,
                response_deserializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.GetPromptVersionByPromptNameResponse.FromString,
                )
        self.InitPaginationByPromptName = channel.unary_unary(
                '/qwak.prompt.v1.prompt.PromptManagerService/InitPaginationByPromptName',
                request_serializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.InitPaginationByPromptNameRequest.SerializeToString,
                response_deserializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.InitPaginationByPromptNameResponse.FromString,
                )
        self.ListPromptVersionsByPromptName = channel.unary_unary(
                '/qwak.prompt.v1.prompt.PromptManagerService/ListPromptVersionsByPromptName',
                request_serializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.ListPromptVersionsByPromptNameRequest.SerializeToString,
                response_deserializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.ListPromptVersionsByPromptNameResponse.FromString,
                )
        self.DeletePrompt = channel.unary_unary(
                '/qwak.prompt.v1.prompt.PromptManagerService/DeletePrompt',
                request_serializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.DeletePromptRequest.SerializeToString,
                response_deserializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.DeletePromptResponse.FromString,
                )
        self.DeletePromptVersion = channel.unary_unary(
                '/qwak.prompt.v1.prompt.PromptManagerService/DeletePromptVersion',
                request_serializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.DeletePromptVersionRequest.SerializeToString,
                response_deserializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.DeletePromptVersionResponse.FromString,
                )
        self.SetDefaultPromptVersion = channel.unary_unary(
                '/qwak.prompt.v1.prompt.PromptManagerService/SetDefaultPromptVersion',
                request_serializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.SetDefaultPromptVersionRequest.SerializeToString,
                response_deserializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.SetDefaultPromptVersionResponse.FromString,
                )
        self.ListPromptBriefs = channel.unary_unary(
                '/qwak.prompt.v1.prompt.PromptManagerService/ListPromptBriefs',
                request_serializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.ListPromptBriefsRequest.SerializeToString,
                response_deserializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.ListPromptBriefsResponse.FromString,
                )


class PromptManagerServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CreatePrompt(self, request, context):
        """Create a new prompt
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreatePromptVersion(self, request, context):
        """Create new prompt version
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdatePrompt(self, request, context):
        """Update Prompt
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPromptByName(self, request, context):
        """Get prompt with its default version by name
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListPrompts(self, request, context):
        """List all prompts with their default version in the account
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPromptVersionByPromptName(self, request, context):
        """Get prompt version by name and optional version number
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def InitPaginationByPromptName(self, request, context):
        """Init pagination by prompt name
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListPromptVersionsByPromptName(self, request, context):
        """List prompt versions by prompt name
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeletePrompt(self, request, context):
        """Delete prompt
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeletePromptVersion(self, request, context):
        """Delete prompt version
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetDefaultPromptVersion(self, request, context):
        """Set default prompt version
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListPromptBriefs(self, request, context):
        """List all prompts briefs in the account
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_PromptManagerServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreatePrompt': grpc.unary_unary_rpc_method_handler(
                    servicer.CreatePrompt,
                    request_deserializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.CreatePromptRequest.FromString,
                    response_serializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.CreatePromptResponse.SerializeToString,
            ),
            'CreatePromptVersion': grpc.unary_unary_rpc_method_handler(
                    servicer.CreatePromptVersion,
                    request_deserializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.CreatePromptVersionRequest.FromString,
                    response_serializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.CreatePromptVersionResponse.SerializeToString,
            ),
            'UpdatePrompt': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdatePrompt,
                    request_deserializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.UpdatePromptRequest.FromString,
                    response_serializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.UpdatePromptResponse.SerializeToString,
            ),
            'GetPromptByName': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPromptByName,
                    request_deserializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.GetPromptByNameRequest.FromString,
                    response_serializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.GetPromptByNameResponse.SerializeToString,
            ),
            'ListPrompts': grpc.unary_unary_rpc_method_handler(
                    servicer.ListPrompts,
                    request_deserializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.ListPromptsRequest.FromString,
                    response_serializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.ListPromptsResponse.SerializeToString,
            ),
            'GetPromptVersionByPromptName': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPromptVersionByPromptName,
                    request_deserializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.GetPromptVersionByPromptNameRequest.FromString,
                    response_serializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.GetPromptVersionByPromptNameResponse.SerializeToString,
            ),
            'InitPaginationByPromptName': grpc.unary_unary_rpc_method_handler(
                    servicer.InitPaginationByPromptName,
                    request_deserializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.InitPaginationByPromptNameRequest.FromString,
                    response_serializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.InitPaginationByPromptNameResponse.SerializeToString,
            ),
            'ListPromptVersionsByPromptName': grpc.unary_unary_rpc_method_handler(
                    servicer.ListPromptVersionsByPromptName,
                    request_deserializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.ListPromptVersionsByPromptNameRequest.FromString,
                    response_serializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.ListPromptVersionsByPromptNameResponse.SerializeToString,
            ),
            'DeletePrompt': grpc.unary_unary_rpc_method_handler(
                    servicer.DeletePrompt,
                    request_deserializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.DeletePromptRequest.FromString,
                    response_serializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.DeletePromptResponse.SerializeToString,
            ),
            'DeletePromptVersion': grpc.unary_unary_rpc_method_handler(
                    servicer.DeletePromptVersion,
                    request_deserializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.DeletePromptVersionRequest.FromString,
                    response_serializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.DeletePromptVersionResponse.SerializeToString,
            ),
            'SetDefaultPromptVersion': grpc.unary_unary_rpc_method_handler(
                    servicer.SetDefaultPromptVersion,
                    request_deserializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.SetDefaultPromptVersionRequest.FromString,
                    response_serializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.SetDefaultPromptVersionResponse.SerializeToString,
            ),
            'ListPromptBriefs': grpc.unary_unary_rpc_method_handler(
                    servicer.ListPromptBriefs,
                    request_deserializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.ListPromptBriefsRequest.FromString,
                    response_serializer=qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.ListPromptBriefsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'qwak.prompt.v1.prompt.PromptManagerService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class PromptManagerService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CreatePrompt(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.prompt.v1.prompt.PromptManagerService/CreatePrompt',
            qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.CreatePromptRequest.SerializeToString,
            qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.CreatePromptResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreatePromptVersion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.prompt.v1.prompt.PromptManagerService/CreatePromptVersion',
            qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.CreatePromptVersionRequest.SerializeToString,
            qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.CreatePromptVersionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdatePrompt(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.prompt.v1.prompt.PromptManagerService/UpdatePrompt',
            qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.UpdatePromptRequest.SerializeToString,
            qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.UpdatePromptResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetPromptByName(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.prompt.v1.prompt.PromptManagerService/GetPromptByName',
            qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.GetPromptByNameRequest.SerializeToString,
            qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.GetPromptByNameResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListPrompts(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.prompt.v1.prompt.PromptManagerService/ListPrompts',
            qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.ListPromptsRequest.SerializeToString,
            qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.ListPromptsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetPromptVersionByPromptName(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.prompt.v1.prompt.PromptManagerService/GetPromptVersionByPromptName',
            qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.GetPromptVersionByPromptNameRequest.SerializeToString,
            qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.GetPromptVersionByPromptNameResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def InitPaginationByPromptName(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.prompt.v1.prompt.PromptManagerService/InitPaginationByPromptName',
            qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.InitPaginationByPromptNameRequest.SerializeToString,
            qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.InitPaginationByPromptNameResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListPromptVersionsByPromptName(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.prompt.v1.prompt.PromptManagerService/ListPromptVersionsByPromptName',
            qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.ListPromptVersionsByPromptNameRequest.SerializeToString,
            qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.ListPromptVersionsByPromptNameResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeletePrompt(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.prompt.v1.prompt.PromptManagerService/DeletePrompt',
            qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.DeletePromptRequest.SerializeToString,
            qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.DeletePromptResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeletePromptVersion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.prompt.v1.prompt.PromptManagerService/DeletePromptVersion',
            qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.DeletePromptVersionRequest.SerializeToString,
            qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.DeletePromptVersionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetDefaultPromptVersion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.prompt.v1.prompt.PromptManagerService/SetDefaultPromptVersion',
            qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.SetDefaultPromptVersionRequest.SerializeToString,
            qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.SetDefaultPromptVersionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListPromptBriefs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.prompt.v1.prompt.PromptManagerService/ListPromptBriefs',
            qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.ListPromptBriefsRequest.SerializeToString,
            qwak_dot_prompt_dot_v1_dot_prompt_dot_prompt__manager__service__pb2.ListPromptBriefsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _TimeUnit:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _TimeUnitEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_TimeUnit.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    TIME_UNIT_INVALID: _TimeUnit.ValueType  # 0
    TIME_UNIT_WEEKS: _TimeUnit.ValueType  # 3
    TIME_UNIT_DAYS: _TimeUnit.ValueType  # 4
    TIME_UNIT_HOURS: _TimeUnit.ValueType  # 5
    TIME_UNIT_MINUTES: _TimeUnit.ValueType  # 6
    TIME_UNIT_SECONDS: _TimeUnit.ValueType  # 7

class TimeUnit(_TimeUnit, metaclass=_TimeUnitEnumTypeWrapper): ...

TIME_UNIT_INVALID: TimeUnit.ValueType  # 0
TIME_UNIT_WEEKS: TimeUnit.ValueType  # 3
TIME_UNIT_DAYS: TimeUnit.ValueType  # 4
TIME_UNIT_HOURS: TimeUnit.ValueType  # 5
TIME_UNIT_MINUTES: TimeUnit.ValueType  # 6
TIME_UNIT_SECONDS: TimeUnit.ValueType  # 7
global___TimeUnit = TimeUnit

class AggregationField(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TIME_WINDOWS_FIELD_NUMBER: builtins.int
    FIELD_NAME_PREFIX_FIELD_NUMBER: builtins.int
    COUNT_FIELD_NUMBER: builtins.int
    SUM_FIELD_NUMBER: builtins.int
    MAX_FIELD_NUMBER: builtins.int
    MIN_FIELD_NUMBER: builtins.int
    AVG_FIELD_NUMBER: builtins.int
    SAMPLE_VARIANCE_FIELD_NUMBER: builtins.int
    POPULATION_VARIANCE_FIELD_NUMBER: builtins.int
    SAMPLE_STDEV_FIELD_NUMBER: builtins.int
    POPULATION_STDEV_FIELD_NUMBER: builtins.int
    BOOLEAN_AND_FIELD_NUMBER: builtins.int
    BOOLEAN_OR_FIELD_NUMBER: builtins.int
    LAST_DISTINCT_N_FIELD_NUMBER: builtins.int
    LAST_N_FIELD_NUMBER: builtins.int
    PERCENTILE_FIELD_NUMBER: builtins.int
    @property
    def time_windows(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TimeWindow]:
        """Aggregation window size in seconds"""
    field_name_prefix: builtins.str
    """Field name prefix"""
    @property
    def count(self) -> global___Count: ...
    @property
    def sum(self) -> global___Sum: ...
    @property
    def max(self) -> global___Max: ...
    @property
    def min(self) -> global___Min: ...
    @property
    def avg(self) -> global___Avg: ...
    @property
    def sample_variance(self) -> global___SampleVariance: ...
    @property
    def population_variance(self) -> global___PopulationVariance: ...
    @property
    def sample_stdev(self) -> global___SampleSTDEV: ...
    @property
    def population_stdev(self) -> global___PopulationSTDEV: ...
    @property
    def boolean_and(self) -> global___BooleanAnd: ...
    @property
    def boolean_or(self) -> global___BooleanOr: ...
    @property
    def last_distinct_n(self) -> global___LastDistinctN: ...
    @property
    def last_n(self) -> global___LastN: ...
    @property
    def percentile(self) -> global___Percentile: ...
    def __init__(
        self,
        *,
        time_windows: collections.abc.Iterable[global___TimeWindow] | None = ...,
        field_name_prefix: builtins.str = ...,
        count: global___Count | None = ...,
        sum: global___Sum | None = ...,
        max: global___Max | None = ...,
        min: global___Min | None = ...,
        avg: global___Avg | None = ...,
        sample_variance: global___SampleVariance | None = ...,
        population_variance: global___PopulationVariance | None = ...,
        sample_stdev: global___SampleSTDEV | None = ...,
        population_stdev: global___PopulationSTDEV | None = ...,
        boolean_and: global___BooleanAnd | None = ...,
        boolean_or: global___BooleanOr | None = ...,
        last_distinct_n: global___LastDistinctN | None = ...,
        last_n: global___LastN | None = ...,
        percentile: global___Percentile | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["aggregator", b"aggregator", "avg", b"avg", "boolean_and", b"boolean_and", "boolean_or", b"boolean_or", "count", b"count", "last_distinct_n", b"last_distinct_n", "last_n", b"last_n", "max", b"max", "min", b"min", "percentile", b"percentile", "population_stdev", b"population_stdev", "population_variance", b"population_variance", "sample_stdev", b"sample_stdev", "sample_variance", b"sample_variance", "sum", b"sum"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["aggregator", b"aggregator", "avg", b"avg", "boolean_and", b"boolean_and", "boolean_or", b"boolean_or", "count", b"count", "field_name_prefix", b"field_name_prefix", "last_distinct_n", b"last_distinct_n", "last_n", b"last_n", "max", b"max", "min", b"min", "percentile", b"percentile", "population_stdev", b"population_stdev", "population_variance", b"population_variance", "sample_stdev", b"sample_stdev", "sample_variance", b"sample_variance", "sum", b"sum", "time_windows", b"time_windows"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["aggregator", b"aggregator"]) -> typing_extensions.Literal["count", "sum", "max", "min", "avg", "sample_variance", "population_variance", "sample_stdev", "population_stdev", "boolean_and", "boolean_or", "last_distinct_n", "last_n", "percentile"] | None: ...

global___AggregationField = AggregationField

class TimeWindow(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TIME_UNIT_FIELD_NUMBER: builtins.int
    LENGTH_FIELD_NUMBER: builtins.int
    time_unit: global___TimeUnit.ValueType
    """Timeframe - hours, days, minutes, hours, etc"""
    length: builtins.int
    """time window length"""
    def __init__(
        self,
        *,
        time_unit: global___TimeUnit.ValueType = ...,
        length: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["length", b"length", "time_unit", b"time_unit"]) -> None: ...

global___TimeWindow = TimeWindow

class Count(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FIELD_NAME_FIELD_NUMBER: builtins.int
    field_name: builtins.str
    """Field name"""
    def __init__(
        self,
        *,
        field_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["field_name", b"field_name"]) -> None: ...

global___Count = Count

class Sum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FIELD_NAME_FIELD_NUMBER: builtins.int
    field_name: builtins.str
    """Field name"""
    def __init__(
        self,
        *,
        field_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["field_name", b"field_name"]) -> None: ...

global___Sum = Sum

class Max(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FIELD_NAME_FIELD_NUMBER: builtins.int
    field_name: builtins.str
    """Field name"""
    def __init__(
        self,
        *,
        field_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["field_name", b"field_name"]) -> None: ...

global___Max = Max

class Min(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FIELD_NAME_FIELD_NUMBER: builtins.int
    field_name: builtins.str
    """Field name"""
    def __init__(
        self,
        *,
        field_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["field_name", b"field_name"]) -> None: ...

global___Min = Min

class Avg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FIELD_NAME_FIELD_NUMBER: builtins.int
    field_name: builtins.str
    """Field name"""
    def __init__(
        self,
        *,
        field_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["field_name", b"field_name"]) -> None: ...

global___Avg = Avg

class SampleVariance(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FIELD_NAME_FIELD_NUMBER: builtins.int
    field_name: builtins.str
    """Field name"""
    def __init__(
        self,
        *,
        field_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["field_name", b"field_name"]) -> None: ...

global___SampleVariance = SampleVariance

class PopulationVariance(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FIELD_NAME_FIELD_NUMBER: builtins.int
    field_name: builtins.str
    """Field name"""
    def __init__(
        self,
        *,
        field_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["field_name", b"field_name"]) -> None: ...

global___PopulationVariance = PopulationVariance

class SampleSTDEV(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FIELD_NAME_FIELD_NUMBER: builtins.int
    field_name: builtins.str
    """Field name"""
    def __init__(
        self,
        *,
        field_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["field_name", b"field_name"]) -> None: ...

global___SampleSTDEV = SampleSTDEV

class PopulationSTDEV(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FIELD_NAME_FIELD_NUMBER: builtins.int
    field_name: builtins.str
    """Field name"""
    def __init__(
        self,
        *,
        field_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["field_name", b"field_name"]) -> None: ...

global___PopulationSTDEV = PopulationSTDEV

class BooleanAnd(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FIELD_NAME_FIELD_NUMBER: builtins.int
    field_name: builtins.str
    """Field name"""
    def __init__(
        self,
        *,
        field_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["field_name", b"field_name"]) -> None: ...

global___BooleanAnd = BooleanAnd

class BooleanOr(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FIELD_NAME_FIELD_NUMBER: builtins.int
    field_name: builtins.str
    """Field name"""
    def __init__(
        self,
        *,
        field_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["field_name", b"field_name"]) -> None: ...

global___BooleanOr = BooleanOr

class LastDistinctN(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FIELD_NAME_FIELD_NUMBER: builtins.int
    N_FIELD_NUMBER: builtins.int
    field_name: builtins.str
    """Field name"""
    n: builtins.int
    """value of N"""
    def __init__(
        self,
        *,
        field_name: builtins.str = ...,
        n: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["field_name", b"field_name", "n", b"n"]) -> None: ...

global___LastDistinctN = LastDistinctN

class LastN(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FIELD_NAME_FIELD_NUMBER: builtins.int
    N_FIELD_NUMBER: builtins.int
    field_name: builtins.str
    """Field name"""
    n: builtins.int
    """value of N"""
    def __init__(
        self,
        *,
        field_name: builtins.str = ...,
        n: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["field_name", b"field_name", "n", b"n"]) -> None: ...

global___LastN = LastN

class Percentile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FIELD_NAME_FIELD_NUMBER: builtins.int
    P_FIELD_NUMBER: builtins.int
    field_name: builtins.str
    """Field name"""
    p: builtins.int
    """rank value - an int between 1 and 99. 50 means median etc."""
    def __init__(
        self,
        *,
        field_name: builtins.str = ...,
        p: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["field_name", b"field_name", "p", b"p"]) -> None: ...

global___Percentile = Percentile



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import qwak.user_application.common.v0.resources_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _InstanceTypeFilter:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _InstanceTypeFilterEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_InstanceTypeFilter.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    INSTANCE_TYPE_FILTER_UNSPECIFIED: _InstanceTypeFilter.ValueType  # 0
    INSTANCE_TYPE_FILTER_ALL: _InstanceTypeFilter.ValueType  # 1
    INSTANCE_TYPE_FILTER_CPU: _InstanceTypeFilter.ValueType  # 2
    INSTANCE_TYPE_FILTER_GPU: _InstanceTypeFilter.ValueType  # 3

class InstanceTypeFilter(_InstanceTypeFilter, metaclass=_InstanceTypeFilterEnumTypeWrapper): ...

INSTANCE_TYPE_FILTER_UNSPECIFIED: InstanceTypeFilter.ValueType  # 0
INSTANCE_TYPE_FILTER_ALL: InstanceTypeFilter.ValueType  # 1
INSTANCE_TYPE_FILTER_CPU: InstanceTypeFilter.ValueType  # 2
INSTANCE_TYPE_FILTER_GPU: InstanceTypeFilter.ValueType  # 3
global___InstanceTypeFilter = InstanceTypeFilter

class _InstanceType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _InstanceTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_InstanceType.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    INSTANCE_TYPE_UNSPECIFIED: _InstanceType.ValueType  # 0
    INSTANCE_TYPE_CPU: _InstanceType.ValueType  # 1
    INSTANCE_TYPE_GPU: _InstanceType.ValueType  # 2

class InstanceType(_InstanceType, metaclass=_InstanceTypeEnumTypeWrapper): ...

INSTANCE_TYPE_UNSPECIFIED: InstanceType.ValueType  # 0
INSTANCE_TYPE_CPU: InstanceType.ValueType  # 1
INSTANCE_TYPE_GPU: InstanceType.ValueType  # 2
global___InstanceType = InstanceType

class InstanceTemplateSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    ORDER_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    POD_COMPUTE_RESOURCES_FIELD_NUMBER: builtins.int
    INSTANCE_TYPE_FIELD_NUMBER: builtins.int
    QPU_FIELD_NUMBER: builtins.int
    AWS_SUPPORTED_FIELD_NUMBER: builtins.int
    GCP_SUPPORTED_FIELD_NUMBER: builtins.int
    id: builtins.str
    display_name: builtins.str
    order: builtins.int
    enabled: builtins.bool
    @property
    def pod_compute_resources(self) -> qwak.user_application.common.v0.resources_pb2.PodComputeResources: ...
    instance_type: global___InstanceType.ValueType
    qpu: builtins.float
    aws_supported: builtins.bool
    gcp_supported: builtins.bool
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        display_name: builtins.str = ...,
        order: builtins.int = ...,
        enabled: builtins.bool = ...,
        pod_compute_resources: qwak.user_application.common.v0.resources_pb2.PodComputeResources | None = ...,
        instance_type: global___InstanceType.ValueType = ...,
        qpu: builtins.float = ...,
        aws_supported: builtins.bool = ...,
        gcp_supported: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pod_compute_resources", b"pod_compute_resources"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["aws_supported", b"aws_supported", "display_name", b"display_name", "enabled", b"enabled", "gcp_supported", b"gcp_supported", "id", b"id", "instance_type", b"instance_type", "order", b"order", "pod_compute_resources", b"pod_compute_resources", "qpu", b"qpu"]) -> None: ...

global___InstanceTemplateSpec = InstanceTemplateSpec

class InstanceFilter(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INSTANCE_TYPE_FILTER_FIELD_NUMBER: builtins.int
    instance_type_filter: global___InstanceTypeFilter.ValueType
    def __init__(
        self,
        *,
        instance_type_filter: global___InstanceTypeFilter.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["instance_type_filter", b"instance_type_filter"]) -> None: ...

global___InstanceFilter = InstanceFilter



import logging
from logging import Logger

from qwak.inner.build_logic.interface.build_logger_interface import BuildLogger
from qwak.inner.build_logic.interface.build_phase import BuildPhase


PREFIX_FORMAT = "{prefix} - "
EXCEPTION_FORMAT = """Message: {line}
Exception: {e}
"""


class TriggerBuildLogger(BuildLogger):
    def __init__(
        self,
        logger: Logger,
        prefix: str,
        build_phase: BuildPhase,
        verbose: int = 0,
        json_logs: bool = False,
    ) -> None:
        self.logger = logging.LoggerAdapter(
            logger,
            {
                "phase": build_phase.description,
                "phase_id": build_phase.phase_id,
            },
        )
        self.prefix = PREFIX_FORMAT.format(prefix=prefix) if prefix else ""
        self.spinner = None
        self.verbose = verbose
        self.json_logs = json_logs

    def exception(self, line: str, e: BaseException) -> None:
        self.logger.error(
            EXCEPTION_FORMAT.format(line=line, e=e),
            exc_info=False,
        )

    def error(self, line: str) -> None:
        self.logger.error(f"{self.prefix}{line}")

    def warning(self, line: str) -> None:
        self.logger.warning(f"{self.prefix}{line}")

    def info(self, line: str) -> None:
        self.logger.info(f"{self.prefix}{line}")

    def debug(self, line: str) -> None:
        self.logger.debug(f"{self.prefix}{line}")



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/administration/account/v1/terms.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*qwak/administration/account/v1/terms.proto\x12\x1bqwak.administration.account\"H\n\x14\x41\x63\x63ountAcceptedTerms\x12\x30\n\x05terms\x18\x01 \x03(\x0b\x32!.qwak.administration.account.Term\"\x95\x02\n\x04Term\x12Q\n\x15platform_general_term\x18\x01 \x01(\x0b\x32\x30.qwak.administration.account.PlatformGeneralTermH\x00\x12Z\n\x1amodel_library_general_term\x18\x02 \x01(\x0b\x32\x34.qwak.administration.account.ModelLibraryGeneralTermH\x00\x12V\n\x18model_library_model_term\x18\x03 \x01(\x0b\x32\x32.qwak.administration.account.ModelLibraryModelTermH\x00\x42\x06\n\x04term\"\x15\n\x13PlatformGeneralTerm\"\x19\n\x17ModelLibraryGeneralTerm\"2\n\x15ModelLibraryModelTerm\x12\x19\n\x11model_registry_id\x18\x01 \x01(\tB\xb4\x01\n)com.qwak.ai.administration.api.account.v1P\x01Z\x84\x01github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/account/v1;account_v0b\x06proto3')



_ACCOUNTACCEPTEDTERMS = DESCRIPTOR.message_types_by_name['AccountAcceptedTerms']
_TERM = DESCRIPTOR.message_types_by_name['Term']
_PLATFORMGENERALTERM = DESCRIPTOR.message_types_by_name['PlatformGeneralTerm']
_MODELLIBRARYGENERALTERM = DESCRIPTOR.message_types_by_name['ModelLibraryGeneralTerm']
_MODELLIBRARYMODELTERM = DESCRIPTOR.message_types_by_name['ModelLibraryModelTerm']
AccountAcceptedTerms = _reflection.GeneratedProtocolMessageType('AccountAcceptedTerms', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTACCEPTEDTERMS,
  '__module__' : 'qwak.administration.account.v1.terms_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.account.AccountAcceptedTerms)
  })
_sym_db.RegisterMessage(AccountAcceptedTerms)

Term = _reflection.GeneratedProtocolMessageType('Term', (_message.Message,), {
  'DESCRIPTOR' : _TERM,
  '__module__' : 'qwak.administration.account.v1.terms_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.account.Term)
  })
_sym_db.RegisterMessage(Term)

PlatformGeneralTerm = _reflection.GeneratedProtocolMessageType('PlatformGeneralTerm', (_message.Message,), {
  'DESCRIPTOR' : _PLATFORMGENERALTERM,
  '__module__' : 'qwak.administration.account.v1.terms_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.account.PlatformGeneralTerm)
  })
_sym_db.RegisterMessage(PlatformGeneralTerm)

ModelLibraryGeneralTerm = _reflection.GeneratedProtocolMessageType('ModelLibraryGeneralTerm', (_message.Message,), {
  'DESCRIPTOR' : _MODELLIBRARYGENERALTERM,
  '__module__' : 'qwak.administration.account.v1.terms_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.account.ModelLibraryGeneralTerm)
  })
_sym_db.RegisterMessage(ModelLibraryGeneralTerm)

ModelLibraryModelTerm = _reflection.GeneratedProtocolMessageType('ModelLibraryModelTerm', (_message.Message,), {
  'DESCRIPTOR' : _MODELLIBRARYMODELTERM,
  '__module__' : 'qwak.administration.account.v1.terms_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.account.ModelLibraryModelTerm)
  })
_sym_db.RegisterMessage(ModelLibraryModelTerm)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n)com.qwak.ai.administration.api.account.v1P\001Z\204\001github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/account/v1;account_v0'
  _ACCOUNTACCEPTEDTERMS._serialized_start=75
  _ACCOUNTACCEPTEDTERMS._serialized_end=147
  _TERM._serialized_start=150
  _TERM._serialized_end=427
  _PLATFORMGENERALTERM._serialized_start=429
  _PLATFORMGENERALTERM._serialized_end=450
  _MODELLIBRARYGENERALTERM._serialized_start=452
  _MODELLIBRARYGENERALTERM._serialized_end=477
  _MODELLIBRARYMODELTERM._serialized_start=479
  _MODELLIBRARYMODELTERM._serialized_end=529
# @@protoc_insertion_point(module_scope)



from typing import List, Optional, Tuple

import grpc
from _qwak_proto.qwak.monitoring.v0.alerting_channel_management_service_pb2 import (
    CreateAlertingChannelRequest,
    DeleteAlertingChannelRequest,
    GetAlertingChannelRequestByName,
    GetAlertingChannelResponseByName,
    ListAlertingChannelRequest,
    ListAlertingChannelResponse,
    UpdateAlertingChannelRequest,
)
from _qwak_proto.qwak.monitoring.v0.alerting_channel_management_service_pb2_grpc import (
    AlertingChannelManagementServiceStub,
)
from _qwak_proto.qwak.monitoring.v0.alerting_channel_pb2 import (
    AlertingChannelCreateOptions,
    AlertingChannelSpec,
    AlertingChannelUpdateOptions,
)
from dependency_injector.wiring import Provide
from google.protobuf.wrappers_pb2 import StringValue
from qwak.clients.alerts_registry.channel import Channel
from qwak.exceptions import QwakException
from qwak.inner.di_configuration import QwakContainer


class AlertingRegistryClient:
    def __init__(self, grpc_channel=Provide[QwakContainer.core_grpc_channel]):
        self.alerting_channel_mgmt_service = AlertingChannelManagementServiceStub(
            grpc_channel
        )

    def create_alerting_channel(self, channel: Channel) -> None:
        try:
            request = CreateAlertingChannelRequest(
                options=AlertingChannelCreateOptions(
                    name=channel.name,
                    spec=AlertingChannelSpec(
                        configuration=channel.channel_conf.to_proto()
                    ),
                )
            )
            self.alerting_channel_mgmt_service.CreateAlertingChannel(request)
        except grpc.RpcError as rpc_error:
            raise QwakException(
                f"Failed to create alerting channel named: {channel.name}. {rpc_error.details()}"
            )
        except Exception as e:
            raise QwakException(
                f"Failed to create alerting channel named: {channel.name}"
            ) from e

    def update_alerting_channel(self, channel_id: str, channel: Channel) -> None:
        try:
            request = UpdateAlertingChannelRequest(
                options=AlertingChannelUpdateOptions(
                    id=channel_id,
                    name=StringValue(value=channel.name),
                    spec=AlertingChannelSpec(
                        configuration=channel.channel_conf.to_proto()
                    ),
                )
            )
            self.alerting_channel_mgmt_service.UpdateAlertingChannel(request)
        except grpc.RpcError as rpc_error:
            raise QwakException(
                f"Failed to update alerting channel named: {channel.name}. \n{rpc_error.details()}"
            )
        except Exception as e:
            raise QwakException(
                f"Failed to update alerting channel named: {channel.name}"
            ) from e

    def get_alerting_channel(self, channel_name: str) -> Optional[Tuple[str, Channel]]:
        try:
            request = GetAlertingChannelRequestByName(name=channel_name)
            response: GetAlertingChannelResponseByName = (
                self.alerting_channel_mgmt_service.GetAlertingChannelByName(request)
            )

            return response.description.metadata.id, Channel.from_proto(
                response.description
            )
        except grpc.RpcError as rpc_error:
            code, name = rpc_error.code().value
            if code == 5:
                return None, None
            else:
                raise QwakException(
                    f"Failed to get alerting channel name: {channel_name}.\n {rpc_error.details()}"
                )
        except Exception as e:
            raise QwakException(
                f"Failed to get alerting channel name: {channel_name}"
            ) from e

    def list_alerting_channel(self) -> List[Tuple[str, Channel]]:
        try:
            response: ListAlertingChannelResponse = (
                self.list_alerting_channel_from_client()
            )
            return [
                (d.metadata.id, Channel.from_proto(d)) for d in response.description
            ]
        except grpc.RpcError as rpc_error:
            raise QwakException(
                f"Failed to list alerting channels\n {rpc_error.details()}"
            )
        except Exception as e:
            raise QwakException("Failed to list alerting channels") from e

    def delete_alerting_channel(self, channel_name: str):
        try:
            self.alerting_channel_mgmt_service.DeleteAlertingChannel(
                DeleteAlertingChannelRequest(name=channel_name)
            )
        except grpc.RpcError as rpc_error:
            raise QwakException(
                f"Failed to delete an alerting channel named: {channel_name}\n {rpc_error.details()}"
            )
        except Exception as e:
            raise QwakException(
                f"Failed to delete an alerting channel named: {channel_name}"
            ) from e

    def list_alerting_channel_from_client(self) -> ListAlertingChannelResponse:
        """
        Get list of alerting channels from the server
        """
        response: ListAlertingChannelResponse = (
            self.alerting_channel_mgmt_service.ListAlertingChannel(
                ListAlertingChannelRequest()
            )
        )
        return response



from typing import List

import grpc
from _qwak_proto.qwak.instance_template.instance_template_pb2 import (
    InstanceFilter,
    InstanceTemplateSpec,
    InstanceTypeFilter,
)
from _qwak_proto.qwak.instance_template.instance_template_service_pb2 import (
    GetInstanceTemplateRequest,
    GetInstanceTemplateResponse,
    ListInstanceTemplatesRequest,
    ListInstanceTemplatesResponse,
)
from _qwak_proto.qwak.instance_template.instance_template_service_pb2_grpc import (
    InstanceTemplateManagementServiceStub,
)
from dependency_injector.wiring import Provide
from qwak.exceptions import QwakException
from qwak.inner.di_configuration import QwakContainer

GET_INSTANCE_TEMPLATE_ERROR_FORMAT = (
    "An error occurred while trying to get instance template: {e}"
)


class InstanceTemplateManagementClient:
    def __init__(self, grpc_channel=Provide[QwakContainer.core_grpc_channel]):
        self._instance_template_service = InstanceTemplateManagementServiceStub(
            grpc_channel
        )

    def get_instance_template(self, instance_template_id: str) -> InstanceTemplateSpec:
        try:
            result: GetInstanceTemplateResponse = (
                self._instance_template_service.GetInstanceTemplate(
                    GetInstanceTemplateRequest(id=instance_template_id)
                )
            )
            return result.instance_template
        except grpc.RpcError as e:
            raise QwakException(
                GET_INSTANCE_TEMPLATE_ERROR_FORMAT.format(
                    e=e.details(), error_code=e.code()
                )
            )
        except Exception as e:
            raise QwakException(GET_INSTANCE_TEMPLATE_ERROR_FORMAT.format(e=e))

    def list_instance_templates(self) -> List[InstanceTemplateSpec]:
        try:
            result: ListInstanceTemplatesResponse = self._instance_template_service.ListInstanceTemplates(
                ListInstanceTemplatesRequest(
                    optional_instance_filter=InstanceFilter(
                        instance_type_filter=InstanceTypeFilter.INSTANCE_TYPE_FILTER_ALL
                    )
                )
            )
            return list(result.instance_template_list)
        except grpc.RpcError as e:
            raise QwakException(
                GET_INSTANCE_TEMPLATE_ERROR_FORMAT.format(e=e.details()),
                status_code=e.code(),
            )
        except Exception as e:
            raise QwakException(GET_INSTANCE_TEMPLATE_ERROR_FORMAT.format(e=e))



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/analytics/analytics_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.analytics import analytics_pb2 as qwak_dot_analytics_dot_analytics__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&qwak/analytics/analytics_service.proto\x12\x0eqwak.analytics\x1a\x1eqwak/analytics/analytics.proto\"\x1d\n\x0cQueryRequest\x12\r\n\x05query\x18\x01 \x01(\t\"!\n\rQueryResponse\x12\x10\n\x08query_id\x18\x01 \x01(\t\"\'\n\x16\x45xecuteDdlQueryRequest\x12\r\n\x05query\x18\x01 \x01(\t\"+\n\x17\x45xecuteDdlQueryResponse\x12\x10\n\x08query_id\x18\x01 \x01(\t\"T\n\x1aGetQueryResultsPageRequest\x12\x10\n\x08query_id\x18\x01 \x01(\t\x12\x0f\n\x07page_id\x18\x02 \x01(\t\x12\x13\n\x0bmax_results\x18\x03 \x01(\x05\"\xa2\x01\n\x1bGetQueryResultsPageResponse\x12+\n\x06status\x18\x01 \x01(\x0e\x32\x1b.qwak.analytics.QueryStatus\x12\x16\n\x0e\x66\x61ilure_reason\x18\x04 \x01(\t\x12\x14\n\x0cnext_page_id\x18\x02 \x01(\t\x12(\n\x04\x64\x61ta\x18\x03 \x01(\x0b\x32\x1a.qwak.analytics.ResultData\")\n\x15GetQueryStatusRequest\x12\x10\n\x08query_id\x18\x01 \x01(\t\"]\n\x16GetQueryStatusResponse\x12+\n\x06status\x18\x01 \x01(\x0e\x32\x1b.qwak.analytics.QueryStatus\x12\x16\n\x0e\x66\x61ilure_reason\x18\x02 \x01(\t\"A\n\x14\x44\x65scribeTableRequest\x12\x12\n\ntable_name\x18\x01 \x01(\t\x12\x15\n\rdatabase_name\x18\x02 \x01(\t\"Y\n\x15\x44\x65scribeTableResponse\x12\x12\n\ntable_name\x18\x01 \x01(\t\x12,\n\x07\x63olumns\x18\x02 \x03(\x0b\x32\x1b.qwak.analytics.TableColumn\"\x12\n\x10ListTableRequest\"(\n\x11ListTableResponse\x12\x13\n\x0btable_names\x18\x01 \x03(\t\"D\n\x12\x43reateTableRequest\x12.\n\x05table\x18\x01 \x01(\x0b\x32\x1f.qwak.analytics.TableDefinition\"\x15\n\x13\x43reateTableResponse\"`\n GetQueryResultDownloadURLRequest\x12<\n\x06params\x18\x01 \x01(\x0b\x32,.qwak.analytics.QueryResultDownloadURLParams\"9\n!GetQueryResultDownloadURLResponse\x12\x14\n\x0c\x64ownload_url\x18\x01 \x01(\t\"B\n\x14OptimizeTableRequest\x12\x16\n\x0e\x65nvironment_id\x18\x01 \x01(\t\x12\x12\n\ntable_name\x18\x02 \x01(\t\")\n\x15OptimizeTableResponse\x12\x10\n\x08query_id\x18\x01 \x01(\t\".\n\x15\x43reateDatabaseRequest\x12\x15\n\rdatabase_name\x18\x01 \x01(\t\"\x18\n\x16\x43reateDatabaseResponse2\xdd\x07\n\x15\x41nalyticsQueryService\x12\x44\n\x05Query\x12\x1c.qwak.analytics.QueryRequest\x1a\x1d.qwak.analytics.QueryResponse\x12\x62\n\x0f\x45xecuteDdlQuery\x12&.qwak.analytics.ExecuteDdlQueryRequest\x1a\'.qwak.analytics.ExecuteDdlQueryResponse\x12n\n\x13GetQueryResultsPage\x12*.qwak.analytics.GetQueryResultsPageRequest\x1a+.qwak.analytics.GetQueryResultsPageResponse\x12_\n\x0eGetQueryStatus\x12%.qwak.analytics.GetQueryStatusRequest\x1a&.qwak.analytics.GetQueryStatusResponse\x12\\\n\rDescribeTable\x12$.qwak.analytics.DescribeTableRequest\x1a%.qwak.analytics.DescribeTableResponse\x12Q\n\nListTables\x12 .qwak.analytics.ListTableRequest\x1a!.qwak.analytics.ListTableResponse\x12V\n\x0b\x43reateTable\x12\".qwak.analytics.CreateTableRequest\x1a#.qwak.analytics.CreateTableResponse\x12\x80\x01\n\x19GetQueryResultDownloadURL\x12\x30.qwak.analytics.GetQueryResultDownloadURLRequest\x1a\x31.qwak.analytics.GetQueryResultDownloadURLResponse\x12\\\n\rOptimizeTable\x12$.qwak.analytics.OptimizeTableRequest\x1a%.qwak.analytics.OptimizeTableResponse\x12_\n\x0e\x43reateDatabase\x12%.qwak.analytics.CreateDatabaseRequest\x1a&.qwak.analytics.CreateDatabaseResponseB\x86\x01\n\x19\x63om.qwak.ai.analytics.apiP\x01Zggithub.com/qwak-ai/qwak-platform/services/core/java/analytics/analytics-api/pb/qwak/analytics;analyticsb\x06proto3')



_QUERYREQUEST = DESCRIPTOR.message_types_by_name['QueryRequest']
_QUERYRESPONSE = DESCRIPTOR.message_types_by_name['QueryResponse']
_EXECUTEDDLQUERYREQUEST = DESCRIPTOR.message_types_by_name['ExecuteDdlQueryRequest']
_EXECUTEDDLQUERYRESPONSE = DESCRIPTOR.message_types_by_name['ExecuteDdlQueryResponse']
_GETQUERYRESULTSPAGEREQUEST = DESCRIPTOR.message_types_by_name['GetQueryResultsPageRequest']
_GETQUERYRESULTSPAGERESPONSE = DESCRIPTOR.message_types_by_name['GetQueryResultsPageResponse']
_GETQUERYSTATUSREQUEST = DESCRIPTOR.message_types_by_name['GetQueryStatusRequest']
_GETQUERYSTATUSRESPONSE = DESCRIPTOR.message_types_by_name['GetQueryStatusResponse']
_DESCRIBETABLEREQUEST = DESCRIPTOR.message_types_by_name['DescribeTableRequest']
_DESCRIBETABLERESPONSE = DESCRIPTOR.message_types_by_name['DescribeTableResponse']
_LISTTABLEREQUEST = DESCRIPTOR.message_types_by_name['ListTableRequest']
_LISTTABLERESPONSE = DESCRIPTOR.message_types_by_name['ListTableResponse']
_CREATETABLEREQUEST = DESCRIPTOR.message_types_by_name['CreateTableRequest']
_CREATETABLERESPONSE = DESCRIPTOR.message_types_by_name['CreateTableResponse']
_GETQUERYRESULTDOWNLOADURLREQUEST = DESCRIPTOR.message_types_by_name['GetQueryResultDownloadURLRequest']
_GETQUERYRESULTDOWNLOADURLRESPONSE = DESCRIPTOR.message_types_by_name['GetQueryResultDownloadURLResponse']
_OPTIMIZETABLEREQUEST = DESCRIPTOR.message_types_by_name['OptimizeTableRequest']
_OPTIMIZETABLERESPONSE = DESCRIPTOR.message_types_by_name['OptimizeTableResponse']
_CREATEDATABASEREQUEST = DESCRIPTOR.message_types_by_name['CreateDatabaseRequest']
_CREATEDATABASERESPONSE = DESCRIPTOR.message_types_by_name['CreateDatabaseResponse']
QueryRequest = _reflection.GeneratedProtocolMessageType('QueryRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYREQUEST,
  '__module__' : 'qwak.analytics.analytics_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.analytics.QueryRequest)
  })
_sym_db.RegisterMessage(QueryRequest)

QueryResponse = _reflection.GeneratedProtocolMessageType('QueryResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYRESPONSE,
  '__module__' : 'qwak.analytics.analytics_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.analytics.QueryResponse)
  })
_sym_db.RegisterMessage(QueryResponse)

ExecuteDdlQueryRequest = _reflection.GeneratedProtocolMessageType('ExecuteDdlQueryRequest', (_message.Message,), {
  'DESCRIPTOR' : _EXECUTEDDLQUERYREQUEST,
  '__module__' : 'qwak.analytics.analytics_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.analytics.ExecuteDdlQueryRequest)
  })
_sym_db.RegisterMessage(ExecuteDdlQueryRequest)

ExecuteDdlQueryResponse = _reflection.GeneratedProtocolMessageType('ExecuteDdlQueryResponse', (_message.Message,), {
  'DESCRIPTOR' : _EXECUTEDDLQUERYRESPONSE,
  '__module__' : 'qwak.analytics.analytics_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.analytics.ExecuteDdlQueryResponse)
  })
_sym_db.RegisterMessage(ExecuteDdlQueryResponse)

GetQueryResultsPageRequest = _reflection.GeneratedProtocolMessageType('GetQueryResultsPageRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETQUERYRESULTSPAGEREQUEST,
  '__module__' : 'qwak.analytics.analytics_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.analytics.GetQueryResultsPageRequest)
  })
_sym_db.RegisterMessage(GetQueryResultsPageRequest)

GetQueryResultsPageResponse = _reflection.GeneratedProtocolMessageType('GetQueryResultsPageResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETQUERYRESULTSPAGERESPONSE,
  '__module__' : 'qwak.analytics.analytics_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.analytics.GetQueryResultsPageResponse)
  })
_sym_db.RegisterMessage(GetQueryResultsPageResponse)

GetQueryStatusRequest = _reflection.GeneratedProtocolMessageType('GetQueryStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETQUERYSTATUSREQUEST,
  '__module__' : 'qwak.analytics.analytics_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.analytics.GetQueryStatusRequest)
  })
_sym_db.RegisterMessage(GetQueryStatusRequest)

GetQueryStatusResponse = _reflection.GeneratedProtocolMessageType('GetQueryStatusResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETQUERYSTATUSRESPONSE,
  '__module__' : 'qwak.analytics.analytics_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.analytics.GetQueryStatusResponse)
  })
_sym_db.RegisterMessage(GetQueryStatusResponse)

DescribeTableRequest = _reflection.GeneratedProtocolMessageType('DescribeTableRequest', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBETABLEREQUEST,
  '__module__' : 'qwak.analytics.analytics_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.analytics.DescribeTableRequest)
  })
_sym_db.RegisterMessage(DescribeTableRequest)

DescribeTableResponse = _reflection.GeneratedProtocolMessageType('DescribeTableResponse', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBETABLERESPONSE,
  '__module__' : 'qwak.analytics.analytics_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.analytics.DescribeTableResponse)
  })
_sym_db.RegisterMessage(DescribeTableResponse)

ListTableRequest = _reflection.GeneratedProtocolMessageType('ListTableRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTTABLEREQUEST,
  '__module__' : 'qwak.analytics.analytics_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.analytics.ListTableRequest)
  })
_sym_db.RegisterMessage(ListTableRequest)

ListTableResponse = _reflection.GeneratedProtocolMessageType('ListTableResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTTABLERESPONSE,
  '__module__' : 'qwak.analytics.analytics_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.analytics.ListTableResponse)
  })
_sym_db.RegisterMessage(ListTableResponse)

CreateTableRequest = _reflection.GeneratedProtocolMessageType('CreateTableRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATETABLEREQUEST,
  '__module__' : 'qwak.analytics.analytics_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.analytics.CreateTableRequest)
  })
_sym_db.RegisterMessage(CreateTableRequest)

CreateTableResponse = _reflection.GeneratedProtocolMessageType('CreateTableResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATETABLERESPONSE,
  '__module__' : 'qwak.analytics.analytics_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.analytics.CreateTableResponse)
  })
_sym_db.RegisterMessage(CreateTableResponse)

GetQueryResultDownloadURLRequest = _reflection.GeneratedProtocolMessageType('GetQueryResultDownloadURLRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETQUERYRESULTDOWNLOADURLREQUEST,
  '__module__' : 'qwak.analytics.analytics_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.analytics.GetQueryResultDownloadURLRequest)
  })
_sym_db.RegisterMessage(GetQueryResultDownloadURLRequest)

GetQueryResultDownloadURLResponse = _reflection.GeneratedProtocolMessageType('GetQueryResultDownloadURLResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETQUERYRESULTDOWNLOADURLRESPONSE,
  '__module__' : 'qwak.analytics.analytics_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.analytics.GetQueryResultDownloadURLResponse)
  })
_sym_db.RegisterMessage(GetQueryResultDownloadURLResponse)

OptimizeTableRequest = _reflection.GeneratedProtocolMessageType('OptimizeTableRequest', (_message.Message,), {
  'DESCRIPTOR' : _OPTIMIZETABLEREQUEST,
  '__module__' : 'qwak.analytics.analytics_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.analytics.OptimizeTableRequest)
  })
_sym_db.RegisterMessage(OptimizeTableRequest)

OptimizeTableResponse = _reflection.GeneratedProtocolMessageType('OptimizeTableResponse', (_message.Message,), {
  'DESCRIPTOR' : _OPTIMIZETABLERESPONSE,
  '__module__' : 'qwak.analytics.analytics_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.analytics.OptimizeTableResponse)
  })
_sym_db.RegisterMessage(OptimizeTableResponse)

CreateDatabaseRequest = _reflection.GeneratedProtocolMessageType('CreateDatabaseRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATABASEREQUEST,
  '__module__' : 'qwak.analytics.analytics_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.analytics.CreateDatabaseRequest)
  })
_sym_db.RegisterMessage(CreateDatabaseRequest)

CreateDatabaseResponse = _reflection.GeneratedProtocolMessageType('CreateDatabaseResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATABASERESPONSE,
  '__module__' : 'qwak.analytics.analytics_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.analytics.CreateDatabaseResponse)
  })
_sym_db.RegisterMessage(CreateDatabaseResponse)

_ANALYTICSQUERYSERVICE = DESCRIPTOR.services_by_name['AnalyticsQueryService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031com.qwak.ai.analytics.apiP\001Zggithub.com/qwak-ai/qwak-platform/services/core/java/analytics/analytics-api/pb/qwak/analytics;analytics'
  _QUERYREQUEST._serialized_start=90
  _QUERYREQUEST._serialized_end=119
  _QUERYRESPONSE._serialized_start=121
  _QUERYRESPONSE._serialized_end=154
  _EXECUTEDDLQUERYREQUEST._serialized_start=156
  _EXECUTEDDLQUERYREQUEST._serialized_end=195
  _EXECUTEDDLQUERYRESPONSE._serialized_start=197
  _EXECUTEDDLQUERYRESPONSE._serialized_end=240
  _GETQUERYRESULTSPAGEREQUEST._serialized_start=242
  _GETQUERYRESULTSPAGEREQUEST._serialized_end=326
  _GETQUERYRESULTSPAGERESPONSE._serialized_start=329
  _GETQUERYRESULTSPAGERESPONSE._serialized_end=491
  _GETQUERYSTATUSREQUEST._serialized_start=493
  _GETQUERYSTATUSREQUEST._serialized_end=534
  _GETQUERYSTATUSRESPONSE._serialized_start=536
  _GETQUERYSTATUSRESPONSE._serialized_end=629
  _DESCRIBETABLEREQUEST._serialized_start=631
  _DESCRIBETABLEREQUEST._serialized_end=696
  _DESCRIBETABLERESPONSE._serialized_start=698
  _DESCRIBETABLERESPONSE._serialized_end=787
  _LISTTABLEREQUEST._serialized_start=789
  _LISTTABLEREQUEST._serialized_end=807
  _LISTTABLERESPONSE._serialized_start=809
  _LISTTABLERESPONSE._serialized_end=849
  _CREATETABLEREQUEST._serialized_start=851
  _CREATETABLEREQUEST._serialized_end=919
  _CREATETABLERESPONSE._serialized_start=921
  _CREATETABLERESPONSE._serialized_end=942
  _GETQUERYRESULTDOWNLOADURLREQUEST._serialized_start=944
  _GETQUERYRESULTDOWNLOADURLREQUEST._serialized_end=1040
  _GETQUERYRESULTDOWNLOADURLRESPONSE._serialized_start=1042
  _GETQUERYRESULTDOWNLOADURLRESPONSE._serialized_end=1099
  _OPTIMIZETABLEREQUEST._serialized_start=1101
  _OPTIMIZETABLEREQUEST._serialized_end=1167
  _OPTIMIZETABLERESPONSE._serialized_start=1169
  _OPTIMIZETABLERESPONSE._serialized_end=1210
  _CREATEDATABASEREQUEST._serialized_start=1212
  _CREATEDATABASEREQUEST._serialized_end=1258
  _CREATEDATABASERESPONSE._serialized_start=1260
  _CREATEDATABASERESPONSE._serialized_end=1284
  _ANALYTICSQUERYSERVICE._serialized_start=1287
  _ANALYTICSQUERYSERVICE._serialized_end=2276
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _SparkAppType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _SparkAppTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_SparkAppType.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    SPARK_APP_TYPE_INVALID: _SparkAppType.ValueType  # 0
    SPARK_APP_TYPE_BATCH_INGESTION: _SparkAppType.ValueType  # 1
    SPARK_APP_TYPE_BATCH_BACKFILL: _SparkAppType.ValueType  # 2
    SPARK_APP_TYPE_BATCH_DELETION: _SparkAppType.ValueType  # 3
    SPARK_APP_TYPE_STREAMING_ONLINE: _SparkAppType.ValueType  # 4
    SPARK_APP_TYPE_STREAMING_OFFLINE: _SparkAppType.ValueType  # 5
    SPARK_APP_TYPE_STREAMING_BACKFILL: _SparkAppType.ValueType  # 6
    SPARK_APP_TYPE_STREAMING_DELETION: _SparkAppType.ValueType  # 7
    SPARK_APP_TYPE_STREAMING_AGGR_ROWLEVEL: _SparkAppType.ValueType  # 8
    SPARK_APP_TYPE_STREAMING_AGGR_COMPACTION: _SparkAppType.ValueType  # 9
    SPARK_APP_TYPE_STREAMING_AGGR_BACKFILL: _SparkAppType.ValueType  # 10
    SPARK_APP_TYPE_STREAMING_AGGR_DELETION: _SparkAppType.ValueType  # 11

class SparkAppType(_SparkAppType, metaclass=_SparkAppTypeEnumTypeWrapper): ...

SPARK_APP_TYPE_INVALID: SparkAppType.ValueType  # 0
SPARK_APP_TYPE_BATCH_INGESTION: SparkAppType.ValueType  # 1
SPARK_APP_TYPE_BATCH_BACKFILL: SparkAppType.ValueType  # 2
SPARK_APP_TYPE_BATCH_DELETION: SparkAppType.ValueType  # 3
SPARK_APP_TYPE_STREAMING_ONLINE: SparkAppType.ValueType  # 4
SPARK_APP_TYPE_STREAMING_OFFLINE: SparkAppType.ValueType  # 5
SPARK_APP_TYPE_STREAMING_BACKFILL: SparkAppType.ValueType  # 6
SPARK_APP_TYPE_STREAMING_DELETION: SparkAppType.ValueType  # 7
SPARK_APP_TYPE_STREAMING_AGGR_ROWLEVEL: SparkAppType.ValueType  # 8
SPARK_APP_TYPE_STREAMING_AGGR_COMPACTION: SparkAppType.ValueType  # 9
SPARK_APP_TYPE_STREAMING_AGGR_BACKFILL: SparkAppType.ValueType  # 10
SPARK_APP_TYPE_STREAMING_AGGR_DELETION: SparkAppType.ValueType  # 11
global___SparkAppType = SparkAppType

class _SparkAppStateType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _SparkAppStateTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_SparkAppStateType.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    SPARK_APP_STATE_INVALID: _SparkAppStateType.ValueType  # 0
    SPARK_APP_STATE_COMPLETED: _SparkAppStateType.ValueType  # 1
    SPARK_APP_STATE_FAILED: _SparkAppStateType.ValueType  # 2
    SPARK_APP_STATE_SUBMISSION_FAILED: _SparkAppStateType.ValueType  # 3
    SPARK_APP_STATE_FAILING: _SparkAppStateType.ValueType  # 4
    SPARK_APP_STATE_INVALIDATING: _SparkAppStateType.ValueType  # 5
    SPARK_APP_STATE_EMPTY: _SparkAppStateType.ValueType  # 6
    """corresponds to "" in sparkoperator.k8s.io/v1beta2.ApplicationStateType"""
    SPARK_APP_STATE_PENDING_RERUN: _SparkAppStateType.ValueType  # 7
    SPARK_APP_STATE_RUNNING: _SparkAppStateType.ValueType  # 8
    SPARK_APP_STATE_SUBMITTED: _SparkAppStateType.ValueType  # 9
    SPARK_APP_STATE_SUCCEEDING: _SparkAppStateType.ValueType  # 10
    SPARK_APP_STATE_UNKNOWN: _SparkAppStateType.ValueType  # 11

class SparkAppStateType(_SparkAppStateType, metaclass=_SparkAppStateTypeEnumTypeWrapper): ...

SPARK_APP_STATE_INVALID: SparkAppStateType.ValueType  # 0
SPARK_APP_STATE_COMPLETED: SparkAppStateType.ValueType  # 1
SPARK_APP_STATE_FAILED: SparkAppStateType.ValueType  # 2
SPARK_APP_STATE_SUBMISSION_FAILED: SparkAppStateType.ValueType  # 3
SPARK_APP_STATE_FAILING: SparkAppStateType.ValueType  # 4
SPARK_APP_STATE_INVALIDATING: SparkAppStateType.ValueType  # 5
SPARK_APP_STATE_EMPTY: SparkAppStateType.ValueType  # 6
"""corresponds to "" in sparkoperator.k8s.io/v1beta2.ApplicationStateType"""
SPARK_APP_STATE_PENDING_RERUN: SparkAppStateType.ValueType  # 7
SPARK_APP_STATE_RUNNING: SparkAppStateType.ValueType  # 8
SPARK_APP_STATE_SUBMITTED: SparkAppStateType.ValueType  # 9
SPARK_APP_STATE_SUCCEEDING: SparkAppStateType.ValueType  # 10
SPARK_APP_STATE_UNKNOWN: SparkAppStateType.ValueType  # 11
global___SparkAppStateType = SparkAppStateType

class SparkExecutionState(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class ApplicationLabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    APPLICATION_ID_FIELD_NUMBER: builtins.int
    SPARK_APPLICATION_TYPE_FIELD_NUMBER: builtins.int
    SPARK_APP_STATE_FIELD_NUMBER: builtins.int
    APPLICATIONLABELS_FIELD_NUMBER: builtins.int
    application_id: builtins.str
    """spark application ID"""
    spark_application_type: global___SparkAppType.ValueType
    """Type of spark Application"""
    @property
    def spark_app_state(self) -> global___SparkAppState:
        """directly mimics sparkoperator.k8s.io/v1beta2.ApplicationState"""
    @property
    def applicationLabels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Labels set on the application itself"""
    def __init__(
        self,
        *,
        application_id: builtins.str = ...,
        spark_application_type: global___SparkAppType.ValueType = ...,
        spark_app_state: global___SparkAppState | None = ...,
        applicationLabels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["spark_app_state", b"spark_app_state", "state_descriptor", b"state_descriptor"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["applicationLabels", b"applicationLabels", "application_id", b"application_id", "spark_app_state", b"spark_app_state", "spark_application_type", b"spark_application_type", "state_descriptor", b"state_descriptor"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["state_descriptor", b"state_descriptor"]) -> typing_extensions.Literal["spark_app_state"] | None: ...

global___SparkExecutionState = SparkExecutionState

class SparkAppState(google.protobuf.message.Message):
    """directly mimics sparkoperator.k8s.io/v1beta2.ApplicationState"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATE_TYPE_FIELD_NUMBER: builtins.int
    ERROR_MESSAGE_FIELD_NUMBER: builtins.int
    state_type: global___SparkAppStateType.ValueType
    error_message: builtins.str
    def __init__(
        self,
        *,
        state_type: global___SparkAppStateType.ValueType = ...,
        error_message: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["error_message", b"error_message", "state_type", b"state_type"]) -> None: ...

global___SparkAppState = SparkAppState
